@@ -1,4 +1,4 @@
-package FU 1.0;
+package FU 1.1;
 use v5.36;
 use Carp 'confess', 'croak';
 use IO::Socket;
@@ -217,17 +217,12 @@ sub monitor_path { push @monitor_paths, @_ }
 sub monitor_check :prototype(&) { $monitor_check = $_[0] }
 
 sub _monitor {
-    state %data;
     return 1 if $monitor_check && $monitor_check->();
 
     require File::Find;
     eval {
         File::Find::find({
-            wanted => sub {
-                my $m = (stat)[9];
-                $data{$_} //= $m;
-                die if $m > $data{$_};
-            },
+            wanted => sub { die if (-M) < 0 },
             no_chdir => 1
         }, grep -e, $scriptpath, values %INC, @monitor_paths);
         0
@@ -994,7 +989,7 @@ FU - A Lean and Efficient Zero-Dependency Web Framework.
   }
 
   FU::get qr{/hello/(.+)}, sub($who) {
-      my_html_ "Website title", sub {
+      myhtml_ "Website title", sub {
           h1_ "Hello, $who!";
       };
   };
@@ -1097,7 +1092,7 @@ returning strings deal with perl Unicode strings, not raw bytes.
 =item use FU -procname => $name
 
 When the C<-procname> import option is set, FU automatically updates the
-process name (as displayed in L<top(1)> and L<ps(1)>, see `$0`) with
+process name (as displayed in L<top(1)> and L<ps(1)>, see C<$0>) with
 information about the current process, prefixed with the given C<$name>.
 
 =item FU::init_db($info)
